| train_nn_wrapper | R Documentation |
kindling-tidymodels wrapper
Basemodels-tidymodels wrappers
train_nn_wrapper(formula, data, ...)
ffnn_wrapper(formula, data, ...)
rnn_wrapper(formula, data, ...)
formula |
A formula specifying the model (e.g., |
data |
A data frame containing the training data |
... |
Additional arguments passed to the underlying training function |
This wrapper function is designed to interface with the {tidymodels}
ecosystem, particularly for use with tune::tune_grid() and workflows.
It handles the conversion of tuning parameters (especially list-column
parameters from grid_depth()) into the format expected by train_nn().
These wrapper functions are designed to interface with the {tidymodels}
ecosystem, particularly for use with tune::tune_grid() and workflows.
They handle the conversion of tuning parameters (especially list-column
parameters from grid_depth()) into the format expected by ffnn() and rnn().
train_nn_wrapper() returns an "nn_fit_tab" object. See train_nn() for details.
ffnn_wrapper() returns an object of class "ffnn_fit" containing the trained feedforward neural network model and metadata. See ffnn() for details.
rnn_wrapper() returns an object of class "rnn_fit" containing the trained recurrent neural network model and metadata. See rnn() for details.
{tidymodels} interfaceInternal wrapper — use mlp_kindling() + fit() instead.
{tidymodels} interfaceThis is a function to interface into {tidymodels}
(do not use this, use kindling::ffnn() instead).
{tidymodels} interfaceInternal wrapper — use rnn_kindling() + fit() instead.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.